from setuptools import setup

setup(name='distributions_EH',
      version='0.2',
      description='Gaussian and Binomial distributions',
      packages=['distributions_EH'],
      author='Erkan Hatipoglu',
      author_email='e109261@gmail.com',
      zip_safe=False)
